@@ -13,17 +13,18 @@ namespace LiteDB.Benchmarks
         static void Main(string[] args)
         {
             BenchmarkRunner.Run(typeof(Program).Assembly, DefaultConfig.Instance
-                //.With(new BenchmarkDotNet.Filters.AnyCategoriesFilter(new[] {Benchmarks.Constants.Categories.DATA_GEN}))
-                .With(Job.Default.With(CoreRuntime.Core31)
-                    .With(Jit.RyuJit)
-                    .With(CsProjCoreToolchain.NetCoreApp31)
+                //.With(new BenchmarkDotNet.Filters.AnyCategoriesFilter(new[] { Benchmarks.Constants.Categories.GENERAL }))
+                //.AddFilter(new BenchmarkDotNet.Filters.AnyCategoriesFilter([Benchmarks.Constants.Categories.GENERAL]))
+                .AddJob(Job.Default.WithRuntime(CoreRuntime.Core60)
+                    .WithJit(Jit.RyuJit)
+                    .WithToolchain(CsProjCoreToolchain.NetCoreApp60)
                     .WithGcForce(true))
                 /*.With(Job.Default.With(MonoRuntime.Default)
                     .With(Jit.Llvm)
                     .With(new[] {new MonoArgument("--optimize=inline")})
                     .WithGcForce(true))*/
-                .With(MemoryDiagnoser.Default)
-                .With(BenchmarkReportExporter.Default, HtmlExporter.Default, MarkdownExporter.GitHub)
+                .AddDiagnoser(MemoryDiagnoser.Default)
+                .AddExporter(BenchmarkReportExporter.Default, HtmlExporter.Default, MarkdownExporter.GitHub)
                 .KeepBenchmarkFiles());
         }
     }
