@@ -10,13 +10,30 @@ namespace LiteDB.Tests
         public TempFile()
         {
             var path = Path.GetTempPath();
-            var name = "test-" + Guid.NewGuid().ToString("d").Substring(0, 5) + ".db";
+            var name = "litedb-" + Guid.NewGuid().ToString("d").Substring(0, 5) + ".db";
 
             this.Filename = Path.Combine(path, name);
         }
 
+        public TempFile(string original)
+        {
+            var rnd = Guid.NewGuid().ToString("d").Substring(0, 5);
+            var path = Path.GetTempPath();
+            var name = $"litedb-{rnd}.db";
+            var filename = Path.Combine(path, name);
+
+            File.Copy(original, filename, true);
+
+            this.Filename = filename;
+        }
+
         #region Dispose
 
+        public static implicit operator String(TempFile value)
+        {
+            return value.Filename;
+        }
+
         private bool _disposed;
 
         public void Dispose()
@@ -53,5 +70,7 @@ namespace LiteDB.Tests
         public long Size => new FileInfo(this.Filename).Length;
 
         public string ReadAsText() => File.ReadAllText(this.Filename);
+
+        public override string ToString() => this.Filename;
     }
 }
\ No newline at end of file
