@@ -12,7 +12,7 @@ namespace LiteDB
 {
     internal class LinqExpressionVisitor : ExpressionVisitor
     {
-        private static Dictionary<Type, ITypeResolver> _resolver = new Dictionary<Type, ITypeResolver>
+        private static readonly Dictionary<Type, ITypeResolver> _resolver = new Dictionary<Type, ITypeResolver>
         {
             [typeof(BsonValue)] = new BsonValueResolver(),
             [typeof(BsonArray)] = new BsonValueResolver(),
