@@ -1,7 +1,7 @@
 ﻿using System;
+using System.Buffers;
 using System.Collections.Generic;
 using System.IO;
-using System.Text;
 using static LiteDB.Constants;
 
 namespace LiteDB.Engine
@@ -20,6 +20,8 @@ namespace LiteDB.Engine
 
         private bool _isEOF = false;
 
+        private static readonly ArrayPool<byte> _bufferPool = ArrayPool<byte>.Shared;
+
         /// <summary>
         /// Current global cursor position
         /// </summary>
@@ -102,10 +104,10 @@ namespace LiteDB.Engine
                 // fill buffer
                 if (buffer != null)
                 {
-                    Buffer.BlockCopy(_current.Array, 
-                        _current.Offset + _currentPosition, 
-                        buffer, 
-                        offset + bufferPosition, 
+                    Buffer.BlockCopy(_current.Array,
+                        _current.Offset + _currentPosition,
+                        buffer,
+                        offset + bufferPosition,
                         bytesToCopy);
                 }
 
@@ -154,20 +156,20 @@ namespace LiteDB.Engine
             // if fits in current segment, use inner array - otherwise copy from multiples segments
             if (_currentPosition + count <= _current.Count)
             {
-                value = Encoding.UTF8.GetString(_current.Array, _current.Offset + _currentPosition, count);
+                value = StringEncoding.UTF8.GetString(_current.Array, _current.Offset + _currentPosition, count);
 
                 this.MoveForward(count);
             }
             else
             {
                 // rent a buffer to be re-usable
-                var buffer = BufferPool.Rent(count);
+                var buffer = _bufferPool.Rent(count);
 
                 this.Read(buffer, 0, count);
 
-                value = Encoding.UTF8.GetString(buffer, 0, count);
+                value = StringEncoding.UTF8.GetString(buffer, 0, count);
 
-                BufferPool.Return(buffer);
+                _bufferPool.Return(buffer, true);
             }
 
             return value;
@@ -204,7 +206,7 @@ namespace LiteDB.Engine
 
                     this.MoveForward(1); // +1 to '\0'
 
-                    return Encoding.UTF8.GetString(mem.ToArray());
+                    return StringEncoding.UTF8.GetString(mem.ToArray());
                 }
             }
         }
@@ -220,7 +222,7 @@ namespace LiteDB.Engine
             {
                 if (_current[pos] == 0x00)
                 {
-                    value = Encoding.UTF8.GetString(_current.Array, _current.Offset + _currentPosition, count);
+                    value = StringEncoding.UTF8.GetString(_current.Array, _current.Offset + _currentPosition, count);
                     this.MoveForward(count + 1); // +1 means '\0'	
                     return true;
                 }
@@ -251,13 +253,13 @@ namespace LiteDB.Engine
             }
             else
             {
-                var buffer = BufferPool.Rent(size);
+                var buffer = _bufferPool.Rent(size);
 
                 this.Read(buffer, 0, size);
 
                 value = convert(buffer, 0);
 
-                BufferPool.Return(buffer);
+                _bufferPool.Return(buffer, true);
             }
 
             return value;
@@ -328,13 +330,13 @@ namespace LiteDB.Engine
             }
             else
             {
-                var buffer = BufferPool.Rent(12);
+                var buffer = _bufferPool.Rent(12);
 
                 this.Read(buffer, 0, 12);
 
                 value = new ObjectId(buffer, 0);
 
-                BufferPool.Return(buffer);
+                _bufferPool.Return(buffer, true);
             }
 
             return value;
@@ -393,12 +395,12 @@ namespace LiteDB.Engine
                 case BsonType.Int64: return this.ReadInt64();
                 case BsonType.Double: return this.ReadDouble();
                 case BsonType.Decimal: return this.ReadDecimal();
-                
+
                 // Use +1 byte only for length
                 case BsonType.String: return this.ReadString(this.ReadByte());
 
-                case BsonType.Document: return this.ReadDocument(null);
-                case BsonType.Array: return this.ReadArray();
+                case BsonType.Document: return this.ReadDocument(null).GetValue();
+                case BsonType.Array: return this.ReadArray().GetValue();
 
                 // Use +1 byte only for length
                 case BsonType.Binary: return this.ReadBytes(this.ReadByte());
@@ -422,51 +424,66 @@ namespace LiteDB.Engine
         /// <summary>
         /// Read a BsonDocument from reader
         /// </summary>
-        public BsonDocument ReadDocument(HashSet<string> fields = null)
+        public Result<BsonDocument> ReadDocument(HashSet<string> fields = null)
         {
-            var length = this.ReadInt32();
-            var end = _position + length - 5;
-            var remaining = fields == null || fields.Count == 0 ? null : new HashSet<string>(fields, StringComparer.OrdinalIgnoreCase);
-
             var doc = new BsonDocument();
 
-            while (_position < end && (remaining == null || remaining?.Count > 0))
+            try
             {
-                var value = this.ReadElement(remaining, out string name);
+                var length = this.ReadInt32();
+                var end = _position + length - 5;
+                var remaining = fields == null || fields.Count == 0 ? null : new HashSet<string>(fields, StringComparer.OrdinalIgnoreCase);
 
-                // null value means are not selected field
-                if (value != null)
+                while (_position < end && (remaining == null || remaining?.Count > 0))
                 {
-                    doc[name] = value;
+                    var value = this.ReadElement(remaining, out string name);
 
-                    // remove from remaining fields
-                    remaining?.Remove(name);
+                    // null value means are not selected field
+                    if (value != null)
+                    {
+                        doc[name] = value;
+
+                        // remove from remaining fields
+                        remaining?.Remove(name);
+                    }
                 }
+
+                this.MoveForward(1); // skip \0 ** can read disk here!
+
+                return doc;
+            }
+            catch (Exception ex)
+            {
+                return new Result<BsonDocument>(doc, ex);
             }
-
-            this.MoveForward(1); // skip \0
-
-            return doc;
         }
 
         /// <summary>
         /// Read an BsonArray from reader
         /// </summary>
-        public BsonArray ReadArray()
+        public Result<BsonArray> ReadArray()
         {
-            var length = this.ReadInt32();
-            var end = _position + length - 5;
             var arr = new BsonArray();
 
-            while (_position < end)
+            try
             {
-                var value = this.ReadElement(null, out string name);
-                arr.Add(value);
+                var length = this.ReadInt32();
+                var end = _position + length - 5;
+
+                while (_position < end)
+                {
+                    var value = this.ReadElement(null, out string name);
+                    arr.Add(value);
+                }
+
+                this.MoveForward(1); // skip \0
+
+                return arr;
+            }
+            catch (Exception ex)
+            {
+                return new Result<BsonArray>(arr, ex);
             }
-
-            this.MoveForward(1); // skip \0
-
-            return arr;
         }
 
         /// <summary>
@@ -513,11 +530,11 @@ namespace LiteDB.Engine
             }
             else if (type == 0x03) // Document
             {
-                return this.ReadDocument();
+                return this.ReadDocument().GetValue();
             }
             else if (type == 0x04) // Array
             {
-                return this.ReadArray();
+                return this.ReadArray().GetValue();
             }
             else if (type == 0x05) // Binary
             {
