@@ -6,12 +6,21 @@ namespace LiteDB.Engine
     /// <summary>
     /// Interface to read current or old datafile structure - Used to shirnk/upgrade datafile from old LiteDB versions
     /// </summary>
-    interface IFileReader
+    interface IFileReader : IDisposable
     {
+        /// <summary>
+        /// Open and initialize file reader (run before any other command)
+        /// </summary>
+        void Open();
+
+        /// <summary>
+        /// Get all database pragma variables
+        /// </summary>
+        IDictionary<string, BsonValue> GetPragmas();
+
         /// <summary>
         /// Get all collections name from database
         /// </summary>
-        /// <returns></returns>
         IEnumerable<string> GetCollections();
 
         /// <summary>
