@@ -102,8 +102,8 @@ namespace LiteDB.Engine
         /// Get how many bytes are used in footer page at this moment
         /// ((HighestIndex + 1) * 4 bytes per slot: [2 for position, 2 for length])
         /// </summary>
-        public int FooterSize => 
-            (this.HighestIndex == byte.MaxValue ? 
+        public int FooterSize =>
+            (this.HighestIndex == byte.MaxValue ?
             0 :  // no items in page
             ((this.HighestIndex + 1) * SLOT_SIZE)); // 4 bytes PER item (2 to position + 2 to length) - need consider HighestIndex used
 
@@ -282,8 +282,8 @@ namespace LiteDB.Engine
             var position = _buffer.ReadUInt16(positionAddr);
             var length = _buffer.ReadUInt16(lengthAddr);
 
-            ENSURE(this.IsValidPos(position), "invalid segment position");
-            ENSURE(this.IsValidLen(length), "invalid segment length");
+            ENSURE(this.IsValidPos(position), "invalid segment position in index footer: {0}/{1}", this, index);
+            ENSURE(this.IsValidLen(length), "invalid segment length in index footer: {0}/{1}", this, index);
 
             // return buffer slice with content only data
             return _buffer.Slice(position, length);
@@ -408,7 +408,7 @@ namespace LiteDB.Engine
                 this.NextFreePosition = position;
             }
             else
-            { 
+            {
                 // if segment is in middle of the page, add this blocks as fragment block
                 this.FragmentedBytes += length;
             }
@@ -475,7 +475,7 @@ namespace LiteDB.Engine
 
                 if (isLastSegment)
                 {
-                    // if is at end of page, must get back unused blocks 
+                    // if is at end of page, must get back unused blocks
                     this.NextFreePosition -= diff;
                 }
                 else
