@@ -10,7 +10,7 @@ namespace LiteDB.Engine
     /// </summary>
     internal class IndexIn : Index
     {
-        private BsonArray _values;
+        private readonly BsonArray _values;
 
         public IndexIn(string name, BsonArray values, int order)
             : base(name, order)
