@@ -17,6 +17,7 @@ namespace LiteDB.Engine
         private readonly HeaderPage _header;
         private readonly LockService _locker;
         private readonly DiskReader _reader;
+        private readonly DiskService _disk;
         private readonly WalIndexService _walIndex;
 
         // instances from transaction
@@ -32,6 +33,8 @@ namespace LiteDB.Engine
         // local page cache - contains only pages about this collection (but do not contains CollectionPage - use this.CollectionPage)
         private readonly Dictionary<uint, BasePage> _localPages = new Dictionary<uint, BasePage>();
 
+        private bool _disposed;
+
         // expose
         public LockMode Mode => _mode;
         public string CollectionName => _collectionName;
@@ -39,7 +42,17 @@ namespace LiteDB.Engine
         public ICollection<BasePage> LocalPages => _localPages.Values;
         public int ReadVersion => _readVersion;
 
-        public Snapshot(LockMode mode, string collectionName, HeaderPage header, uint transactionID, TransactionPages transPages, LockService locker, WalIndexService walIndex, DiskReader reader, bool addIfNotExists)
+        public Snapshot(
+            LockMode mode, 
+            string collectionName, 
+            HeaderPage header, 
+            uint transactionID, 
+            TransactionPages transPages, 
+            LockService locker, 
+            WalIndexService walIndex, 
+            DiskReader reader, 
+            DiskService disk,
+            bool addIfNotExists)
         {
             _mode = mode;
             _collectionName = collectionName;
@@ -49,6 +62,7 @@ namespace LiteDB.Engine
             _locker = locker;
             _walIndex = walIndex;
             _reader = reader;
+            _disk = disk;
 
             // enter in lock mode according initial mode
             if (mode == LockMode.Write)
@@ -59,7 +73,7 @@ namespace LiteDB.Engine
             // get lastest read version from wal-index
             _readVersion = _walIndex.CurrentReadVersion;
 
-            var srv = new CollectionService(_header, this, _transPages);
+            var srv = new CollectionService(_header, _disk, this, _transPages);
 
             // read collection (create if new - load virtual too)
             srv.Get(_collectionName, addIfNotExists, ref _collectionPage);
@@ -77,6 +91,8 @@ namespace LiteDB.Engine
         /// </summary>
         public IEnumerable<BasePage> GetWritablePages(bool dirty, bool includeCollectionPage)
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
+
             // if snapshot is read only, just exit
             if (_mode == LockMode.Read) yield break;
 
@@ -98,6 +114,8 @@ namespace LiteDB.Engine
         /// </summary>
         public void Clear()
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
+
             // release pages only if snapshot are read only
             if (_mode == LockMode.Read)
             {
@@ -116,9 +134,16 @@ namespace LiteDB.Engine
         /// </summary>
         public void Dispose()
         {
+            if (_disposed)
+            {
+                return;
+            }
+
             // release all data/index pages
             this.Clear();
 
+            _disposed = true;
+
             // release collection page (in read mode)
             if (_mode == LockMode.Read && _collectionPage != null)
             {
@@ -134,20 +159,21 @@ namespace LiteDB.Engine
         #region Page Version functions
 
         /// <summary>
-        /// Get a a valid page for this snapshot (must consider local-index and wal-index)
+        /// Get a valid page for this snapshot (must consider local-index and wal-index)
         /// </summary>
-        public T GetPage<T>(uint pageID)
+        public T GetPage<T>(uint pageID, bool useLatestVersion = false)
             where T : BasePage
         {
-            return this.GetPage<T>(pageID, out var origin, out var position, out var walVersion);
+            return this.GetPage<T>(pageID, out var origin, out var position, out var walVersion, useLatestVersion);
         }
 
         /// <summary>
-        /// Get a a valid page for this snapshot (must consider local-index and wal-index)
+        /// Get a valid page for this snapshot (must consider local-index and wal-index)
         /// </summary>
-        public T GetPage<T>(uint pageID, out FileOrigin origin, out long position, out int walVersion)
+        public T GetPage<T>(uint pageID, out FileOrigin origin, out long position, out int walVersion, bool useLatestVersion = false)
             where T : BasePage
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
             ENSURE(pageID <= _header.LastPageID, "request page must be less or equals lastest page in data file");
 
             // check for header page (return header single instance)
@@ -172,7 +198,7 @@ namespace LiteDB.Engine
             }
 
             // if page is not in local cache, get from disk (log/wal/data)
-            page = this.ReadPage<T>(pageID, out origin, out position, out walVersion);
+            page = this.ReadPage<T>(pageID, out origin, out position, out walVersion, useLatestVersion);
 
             // add into local pages
             _localPages[pageID] = page;
@@ -186,7 +212,7 @@ namespace LiteDB.Engine
         /// <summary>
         /// Read page from disk (dirty, wal or data)
         /// </summary>
-        private T ReadPage<T>(uint pageID, out FileOrigin origin, out long position, out int walVersion)
+        private T ReadPage<T>(uint pageID, out FileOrigin origin, out long position, out int walVersion, bool useLatestVersion = false)
             where T : BasePage
         {
             // if not inside local pages can be a dirty page saved in log file
@@ -206,7 +232,7 @@ namespace LiteDB.Engine
             }
 
             // now, look inside wal-index
-            var pos = _walIndex.GetPageIndex(pageID, _readVersion, out walVersion);
+            var pos = _walIndex.GetPageIndex(pageID, useLatestVersion ? int.MaxValue : _readVersion, out walVersion);
 
             if (pos != long.MaxValue)
             {
@@ -247,6 +273,8 @@ namespace LiteDB.Engine
         /// </summary>
         public DataPage GetFreeDataPage(int bytesLength)
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
+
             var length = bytesLength + BasePage.SLOT_SIZE; // add +4 bytes for footer slot
 
             // get minimum slot to check for free page. Returns -1 if need NewPage
@@ -280,6 +308,8 @@ namespace LiteDB.Engine
         /// </summary>
         public IndexPage GetFreeIndexPage(int bytesLength, ref uint freeIndexPageList)
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
+
             IndexPage page;
 
             // if there is not page in list pages, create new page
@@ -306,6 +336,7 @@ namespace LiteDB.Engine
         public T NewPage<T>()
             where T : BasePage
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
             ENSURE(_collectionPage == null, typeof(T) == typeof(CollectionPage), "if no collection page defined yet, must be first request");
             ENSURE(typeof(T) == typeof(CollectionPage), _collectionPage == null, "there is no new collection page if page already exists");
 
@@ -321,7 +352,7 @@ namespace LiteDB.Engine
                 // try get page from Empty free list
                 if (_header.FreeEmptyPageList != uint.MaxValue)
                 {
-                    var free = this.GetPage<BasePage>(_header.FreeEmptyPageList);
+                    var free = this.GetPage<BasePage>(_header.FreeEmptyPageList, useLatestVersion: true);
 
                     ENSURE(free.PageType == PageType.Empty, "empty page must be defined as empty type");
 
@@ -344,11 +375,21 @@ namespace LiteDB.Engine
 
                     if (newLength > _header.Pragmas.LimitSize) throw new LiteException(0, $"Maximum data file size has been reached: {FileHelper.FormatFileSize(_header.Pragmas.LimitSize)}");
 
-                    // increase LastPageID from shared page
-                    pageID = ++_header.LastPageID;
+                    var savepoint = _header.Savepoint();
+                    try
+                    {
+                        // increase LastPageID from shared page
+                        pageID = ++_header.LastPageID;
 
-                    // request for a new buffer
-                    buffer = _reader.NewPage();
+                        // request for a new buffer
+                        buffer = _reader.NewPage();
+                    }
+                    catch
+                    {
+                        // must revert all header content if any error occurs during header change
+                        _header.Restore(savepoint);
+                        throw;
+                    }
                 }
 
                 // retain a list of created pages to, in a rollback situation, back pages to empty list
@@ -380,6 +421,8 @@ namespace LiteDB.Engine
         /// </summary>
         public void AddOrRemoveFreeDataList(DataPage page)
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
+
             var newSlot = DataPage.FreeIndexSlot(page.FreeBytes);
             var initialSlot = page.PageListSlot;
 
@@ -411,6 +454,8 @@ namespace LiteDB.Engine
         /// </summary>
         public void AddOrRemoveFreeIndexList(IndexPage page, ref uint startPageID)
         {
+            ENSURE(!_disposed, "the snapshot is disposed");
+
             var newSlot = IndexPage.FreeIndexSlot(page.FreeBytes);
             var isOnList = page.PageListSlot == 0;
             var mustKeep = newSlot == 0;
@@ -555,7 +600,9 @@ namespace LiteDB.Engine
         /// </summary>
         public void DropCollection(Action safePoint)
         {
-            var indexer = new IndexService(this, _header.Pragmas.Collation);
+            ENSURE(!_disposed, "the snapshot is disposed");
+
+            var indexer = new IndexService(this, _header.Pragmas.Collation, _disk.MAX_ITEMS_COUNT);
 
             // CollectionPage will be last deleted page (there is no NextPageID from CollectionPage)
             _transPages.FirstDeletedPageID = _collectionPage.PageID;
