@@ -208,7 +208,7 @@ namespace LiteDB
     /// </summary>
     internal class Tokenizer
     {
-        private TextReader _reader;
+        private readonly TextReader _reader;
         private char _char = '\0';
         private Token _ahead = null;
         private bool _eof = false;
